@@ -4,9 +4,10 @@
 #' @author Teun van den Brand <t.vd.brand@nki.nl>
 #' @param layer A \code{Layer} object, typically constructed with a call to a
 #'   \code{geom_*()} or \code{stat_*()} function.
-#' @param dpi An integer of length one setting the desired resolution in dots per inch. (default=NULL)
-#' @param dev A character specifying a device. Can be one of: \code{"cairo"}, \code{"ragg"} or \code{"ragg_png"}. (default="cairo")
-#' @details The default \code{dpi} (\code{NULL} (= let device decide)) can conveniently be controlled by setting the option \code{"ggrastr.default.dpi"} (e.g. \code{option("ggrastr.default.dpi", 30)} for drafting).
+#' @param dpi integer Sets the desired resolution in dots per inch (default=NULL).
+#' @param dev string Specifies the device used, which can be one of: \code{"cairo"}, \code{"ragg"} or \code{"ragg_png"} (default="cairo").
+#' @param scale numeric Scaling factor to modify the raster object size (default=1). The parameter 'scale=1' results in an object size that is unchanged, 'scale'>1 increase the size, and 'scale'<1 decreases the size. These parameters are passed to 'height' and 'width' of grid::grid.raster(). Please refer to 'rasterise()' and 'grid::grid.raster()' for more details.
+#' @details The default \code{dpi} (\code{NULL} (i.e. let the device decide)) can conveniently be controlled by setting the option \code{"ggrastr.default.dpi"} (e.g. \code{option("ggrastr.default.dpi", 30)} for drafting).
 #' @return A modified \code{Layer} object.
 #' @examples
 #' require(ggplot2)
@@ -23,12 +24,32 @@
 #' ggplot(diamonds, aes(carat, depth, z = price)) +
 #'   rasterise(stat_summary_hex(), dev = "ragg")
 #'
+#' # The `scale` argument allows you to render a 'big' plot in small window, or vice versa.
+#' ggplot(faithful, aes(eruptions, waiting)) +
+#'   rasterise(geom_point(), scale = 4)
+#'
 #' @export
-rasterise <- function(layer, dpi = getOption("ggrastr.default.dpi"), dev = "cairo") {
+
+rasterise <- function(layer, dpi = getOption("ggrastr.default.dpi"), dev = "cairo", scale = 1) {
+  
   dev <- match.arg(dev, c("cairo", "ragg", "ragg_png"))
 
-  if (!inherits(layer, "Layer")) {
-    stop("Cannot rasterise an object of class `", class(layer)[1], "`. Must be either 'cairo', 'ragg', or 'ragg_png'.", call. = FALSE)
+  # geom_sf returns a list and requires extra logic here to handle gracefully
+  if (is.list(layer)) {
+    # Check if list contains layers
+    has_layer <- rapply(layer, is.layer, how = "list")
+    has_layer <- vapply(has_layer, function(x) {any(unlist(x))}, logical(1))
+    if (any(has_layer)) {
+      # Recurse through list elements that contain layers
+      layer[has_layer] <- lapply(layer[has_layer], rasterise,
+                                dpi = dpi, dev = dev)
+      return(layer)
+    } # Will hit next error if list doesn't contain layers
+  }
+
+  if (!is.layer(layer)) {
+    stop("Cannot rasterise an object of class `", class(layer)[1], "`.",
+         call. = FALSE)
   }
 
   # Take geom from input layer
@@ -45,6 +66,7 @@ rasterise <- function(layer, dpi = getOption("ggrastr.default.dpi"), dev = "cair
         class(grob) <- c("rasteriser", class(grob))
         grob$dpi <- dpi
         grob$dev <- dev
+        grob$scale <- scale
         return(grob)
       }
     )
@@ -61,7 +83,11 @@ rasterize <- rasterise
 #' @method makeContext rasteriser
 makeContext.rasteriser <- function(x) {
   # Grab viewport information
-  vp <- if(is.null(x$vp)) grid::viewport() else x$vp
+  vp <- if (is.null(x$vp)){
+    grid::viewport()
+  } else{
+    x$vp
+  }
   width <- grid::convertWidth(unit(1, "npc"), "inch", valueOnly = TRUE)
   height <- grid::convertHeight(unit(1, "npc"), "inch", valueOnly = TRUE)
 
@@ -72,12 +98,22 @@ makeContext.rasteriser <- function(x) {
     dpi <- grid::convertWidth(unit(1, "inch"), "pt", valueOnly = TRUE)
   }
   dev <- x$dev
+  scale <- x$scale
 
   # Clean up grob
   x$dev <- NULL
   x$dpi <- NULL
+  x$scale <- NULL
   class(x) <- setdiff(class(x), "rasteriser")
 
+  # Rescale height and width
+  if (scale <= 0 || !is.numeric(scale)) {
+    stop("The parameter 'scale' must be set to a numeric greater than 0")
+  }
+
+  width <- width / scale
+  height <- height / scale
+
   # Track current device
   dev_cur <- grDevices::dev.cur()
   # Reset current device upon function exit
@@ -138,9 +174,16 @@ makeContext.rasteriser <- function(x) {
   # Forward raster grob
   grid::rasterGrob(
     cap, x = 0.5, y = 0.5,
-    height = unit(height, "inch"),
-    width = unit(width, "inch"),
+    height = unit(height * scale, "inch"),
+    width = unit(width * scale, "inch"),
     default.units = "npc",
     just = "center"
   )
 }
+
+
+# Small helper function to test if x is a ggplot2 layer
+#' @keywords internal
+is.layer <- function(x) {
+  inherits(x, "LayerInstance")
+}
